@@ -32,7 +32,7 @@
 #ifndef lint
 static char copyright[] =
 "@(#) Copyright 1994 Purdue Research Foundation.\nAll rights reserved.\n";
-static char *rcsid = "$Id: dnode.c,v 1.15 2002/01/18 20:57:04 abe Exp $";
+static char *rcsid = "$Id: dnode.c,v 1.17 2002/04/19 12:07:33 abe Exp $";
 #endif
 
 
@@ -65,7 +65,7 @@ static char *rcsid = "$Id: dnode.c,v 1.15 2002/01/18 20:57:04 abe Exp $";
  * the kernel uses.  The kernel's rnode struct definition comes from
  * <oncplus/nfs/rnode.h>, a header file IBM does not ship with AIX.
  *
- * The rnode64 struct is for AIX 4.3.3 and above whose "width" is 64.
+ * The rnode64 struct is for AIX above 4.3.3 whose "width" is 64.
  * (See dnode.c for the method used to determine width.)
  */
 
@@ -78,16 +78,16 @@ struct rnode {
 	struct vattr r_attr;		/* cached vnode attributes */
 };
 
-#    if	AIXV>=4330
+#    if	AIXV>4330
 struct rnode64 {
 	caddr_t	r_d1[11];		/* dummies; links? */
 	struct vnode r_vnode;		/* vnode for remote file */
 	struct gnode r_gnode;		/* gnode for remote file */
-	caddr_t r_d2[26];		/* dummies; rnode elements? */
+	caddr_t r_d2[15];		/* dummies; rnode elements? */
 	off_t r_size;			/* client's view of file size (long)*/
 	struct vattr r_attr;		/* cached vnode attributes */
 };
-#    endif	/* AIXV>=4330 */
+#    endif	/* AIXV>4330 */
 #   else	/* AIXA>=2 */
 struct rnode {
 	KA_T d1[7];			/* dummies */
@@ -205,9 +205,9 @@ process_node(va)
 	static char *rp = (char *)&r;
 	static int rsz = sizeof(r);
 
-# if	AIXV>=4330 && AIXA<2
+# if	AIXV>4330 && AIXA<2
 	static struct rnode64 r64;
-# endif	/* AIXV>=4330 && AIXA<2 */
+# endif	/* AIXV>4330 && AIXA<2 */
 
 # if	AIXA<2
 	static int width = -1;
@@ -574,9 +574,9 @@ process_clone_again:
 	     * access parameters accordingly.
 	     */
 
-#  if	AIXV<4330
+#  if	AIXV<=4330
 		width = 32;
-#  else	/* AIXV>=4330 */
+#  else	/* AIXV>4330 */
 		switch ((width = _system_configuration.width)) {
 		case 32:
 		    break;
@@ -591,7 +591,7 @@ process_clone_again:
 			    Pn, width);
 		    width = -2;
 		}
-#  endif	/* AIXV<4330 */
+#  endif	/* AIXV<-4330 */
 
 	    }
 # endif	/* AIXA<2 */
@@ -605,10 +605,10 @@ process_clone_again:
 		    return;
 		}
 
-# if	AIXV<4330 || AIXA>=2
+# if	AIXV<=4330 || AIXA>=2
 		nfs_attr = r.r_attr;
 		nfss = 1;
-# else	/* AIXV>=4330 && AIXA<2 */
+# else	/* AIXV>4330 && AIXA<2 */
 		switch (width) {
 		case 32:
 		    nfs_attr = r.r_attr;
@@ -619,7 +619,7 @@ process_clone_again:
 		    nfss = 1;
 		    break;
 		}
-# endif	/* AIXV<4330 || AIXA>=2 */
+# endif	/* AIXV<=4330 || AIXA>=2 */
 
 	    }
 	    break;
@@ -648,17 +648,15 @@ process_clone_again:
 	     */
 
 	    } else if (g.gn_data) {
-		if (Ntype != N_BLK) {
-		    if (readinode((KA_T)g.gn_data, &i)) {
-			(void) snpf(Namech, Namechl,
-			    "gnode at %s can't read inode: %s",
-			    print_kptr((KA_T)v->v_gnode, tbuf, sizeof(tbuf)),
-			    print_kptr((KA_T)g.gn_data, (char *)NULL, 0));
-			enter_nm(Namech);
-			return;
-		    }
-		    ins = 1;
+		if (readinode((KA_T)g.gn_data, &i)) {
+		    (void) snpf(Namech, Namechl,
+			"gnode at %s can't read inode: %s",
+			print_kptr((KA_T)v->v_gnode, tbuf, sizeof(tbuf)),
+			print_kptr((KA_T)g.gn_data, (char *)NULL, 0));
+		    enter_nm(Namech);
+		    return;
 		}
+		ins = 1;
 	    }
 
 #if	defined(HAS_AFS)
@@ -783,7 +781,6 @@ process_clone_again:
 
 # if	AIXV>=3200
 	case N_BLK:
-	    break;
 	case N_CHR:
 	case N_FIFO:
 	case N_MPC:
@@ -844,7 +841,8 @@ process_clone_again:
 			Lf->sz = (SZOFFTYPE)i.i_size;
 			Lf->sz_def = 1;
 		    }
-		} else if ((type == VCHR || type == VMPC) && !Fsize)
+		} else if (((type == VBLK) || (type == VCHR) || (type == VMPC))
+		       &&  !Fsize)
 		    Lf->off_def = 1;
 		break;
 	    }
@@ -872,8 +870,7 @@ process_clone_again:
 #endif	/* defined(HAS_NFS) */
 
 #if	AIXV>=3200
-	    case N_BLK:				/* no link count? */
-		break;
+	    case N_BLK:
 	    case N_CHR:
 	    case N_FIFO:
 	    case N_MPC:
