@@ -32,7 +32,7 @@
 #ifndef lint
 static char copyright[] =
 "@(#) Copyright 1994 Purdue Research Foundation.\nAll rights reserved.\n";
-static char *rcsid = "$Id: dnode.c,v 1.18 2001/08/14 12:40:12 abe Exp $";
+static char *rcsid = "$Id: dnode.c,v 1.20 2002/04/19 12:09:25 abe Exp $";
 #endif
 
 
@@ -258,7 +258,8 @@ isvlocked(vp)
 	    if (lp->set.l_rsys || lp->set.l_pid != (pid_t)Lp->pid)
 		continue;
 	    if (lp->set.l_whence == 0 && lp->set.l_start == 0
-	    &&  lp->set.l_len == 0x7fffffffffffffff)
+	    &&  ((lp->set.l_len == 0x8000000000000000)
+	    ||   (lp->set.l_len == 0x7fffffffffffffff)))
 		l = 1;
 	    else
 		l = 0;
@@ -607,6 +608,10 @@ process_node(va)
 	} else if (r) {
 	    dev = r->r_attr.va_fsid;
 	    devs = 1;
+	    if ((type == VCHR) || (type == VBLK)) {
+		rdev = r->r_attr.va_rdev;
+		rdevs = 1;
+	    }
 	} else if (s) {
 	    if (vfs && vfs->dev)
 		dev = vfs->dev;
@@ -762,7 +767,7 @@ process_node(va)
 			Lf->sz = (SZOFFTYPE)s5->i_size;
 			Lf->sz_def = 1;
 		    }
-		} else if (type == VCHR && !Fsize)
+		} else if ((type == VBLK) || (type == VCHR) && !Fsize)
 		    Lf->off_def = 1;
 	    }
 	}
@@ -842,6 +847,7 @@ process_node(va)
 	    break;
 	case VBLK:
 	    ty = "VBLK";
+	    Ntype = N_BLK;
 	    break;
 	case VCHR:
 	    ty = "VCHR";
