@@ -32,7 +32,7 @@
 #ifndef lint
 static char copyright[] =
 "@(#) Copyright 1994 Purdue Research Foundation.\nAll rights reserved.\n";
-static char *rcsid = "$Id: dnode.c,v 1.22 2002/01/14 15:55:10 abe Exp $";
+static char *rcsid = "$Id: dnode.c,v 1.23 2002/02/26 15:19:55 abe Exp $";
 #endif
 
 
@@ -559,10 +559,8 @@ process_node(va)
  * Obtain the inode number.
  */
 	if (i) {
-	    if (type != VBLK) {
-		Lf->inode = (unsigned long)i->i_number;
-		Lf->inp_ty = 1;
-	    }
+	    Lf->inode = (unsigned long)i->i_number;
+	    Lf->inp_ty = 1;
 	} else if (n) {
 	    Lf->inode = (unsigned long)n->n_vattr.va_fileid;
 	    Lf->inp_ty = 1;
