@@ -32,7 +32,7 @@
 #ifndef lint
 static char copyright[] =
 "@(#) Copyright 1994 Purdue Research Foundation.\nAll rights reserved.\n";
-static char *rcsid = "$Id: dnode.c,v 1.22 2002/01/14 15:56:06 abe Exp $";
+static char *rcsid = "$Id: dnode.c,v 1.24 2002/04/19 20:53:24 abe Exp $";
 #endif
 
 
@@ -595,10 +595,8 @@ process_node(va)
 #endif	/* defined(HASEXT2FS) */
 
 	case INODE:
-	    if (type != VBLK) {
-		Lf->inode = (unsigned long)i.i_number;
-		Lf->inp_ty = 1;
-	    }
+	    Lf->inode = (unsigned long)i.i_number;
+	    Lf->inp_ty = 1;
 	    break;
 
 #if	defined(HASKERNFS)
@@ -1025,7 +1023,7 @@ process_node(va)
 }
 
 
-#if	defined(OPENBSDV)
+#if	defined(HAS_SYS_PIPEH)
 /*
  * process_pipe() - process a file structure whose type is DTYPE_PIPE
  */
@@ -1076,4 +1074,4 @@ process_pipe(pa)
 	if (Namech[0])
 	    enter_nm(Namech);
 }
-#endif	/* defined(OPENBSDV) */
+#endif	/* defined(HAS_SYS_PIPEH) */
