@@ -32,7 +32,7 @@
 #ifndef lint
 static char copyright[] =
 "@(#) Copyright 1994 Purdue Research Foundation.\nAll rights reserved.\n";
-static char *rcsid = "$Id: ddev.c,v 1.17 2001/08/14 13:08:58 abe Exp $";
+static char *rcsid = "$Id: ddev.c,v 1.18 2002/02/26 15:22:16 abe Exp $";
 #endif
 
 
@@ -43,7 +43,8 @@ static char *rcsid = "$Id: ddev.c,v 1.17 2001/08/14 13:08:58 abe Exp $";
  * Local definitions
  */
 
-#define	LIKE_NODE_TTL	"like device special "
+#define	LIKE_BLK_SPEC	"like block special"
+#define	LIKE_CHR_SPEC	"like character special"
 
 
 /*
@@ -104,14 +105,15 @@ make_devtp(s, p)
 
 
 /*
- * printchdevname() - print character device name
+ * printdevname() - print block or character device name
  */
 
 int
-printchdevname(dev, rdev, f)
+printdevname(dev, rdev, f, nty)
 	dev_t *dev;			/* device */
 	dev_t *rdev;			/* raw device */
 	int f;				/* 1 = print trailing '\n' */
+	int nty;			/* node type: N_BLK or N_CHR */
 {
 	struct clone *c;
 	struct l_dev *dp;
@@ -128,28 +130,44 @@ printchdevname_again:
 
 #endif	/* defined(HASDCACHE) */
 
-	if ((dp = lkupdev(dev, rdev, 1, 0))) {
+#if	defined(HASBLKDEV)
+	if (nty == N_BLK)
+	    dp = lkupbdev(dev, rdev, 1, 0);
+	else
+#endif	/* defined(HASBLKDEV) */
+
+	dp = lkupdev(dev, rdev, 1, 0);
+	if (dp) {
 	    safestrprt(dp->name, stdout, f);
 	    return(1);
 	}
 /*
  * Search device table for a match without inode number and dev.
  */
-	if ((dp = lkupdev(&DevDev, rdev, 0, 0))) {
+
+#if	defined(HASBLKDEV)
+	if (nty == N_BLK)
+	    dp = lkupbdev(&DevDev, rdev, 0, 0);
+	else
+#endif	/* defined(HASBLKDEV) */
+
+	dp = lkupdev(&DevDev, rdev, 0, 0);
+	if (dp) {
 
 	/*
-	 * A raw device match was found.  Record it as a name column addition.
+	 * A match was found.  Record it as a name column addition.
 	 */
-	    char *cp;
+	    char *cp, *ttl;
 	    int len;
 
-	    len = (int)(1 + strlen(LIKE_NODE_TTL) + strlen(dp->name) + 1);
+	    ttl = (nty == N_BLK) ? LIKE_BLK_SPEC : LIKE_CHR_SPEC;
+	    len = (int)(1 + strlen(ttl) + 1 + strlen(dp->name) + 1);
 	    if (!(cp = (char *)malloc((MALLOC_S)(len + 1)))) {
-		(void) fprintf(stderr, "%s: no nma space for: (%s%s)\n",
-		    Pn, LIKE_NODE_TTL, dp->name);
+		(void) fprintf(stderr, "%s: no nma space for: (%s %s)\n",
+		    Pn, ttl, dp->name);
 		Exit(1);
 	    }
-	    (void) snpf(cp, len + 1, "(%s%s)", LIKE_NODE_TTL, dp->name);
+	    (void) snpf(cp, len + 1, "(%s %s)", ttl, dp->name);
 	    (void) add_nma(cp, len);
 	    (void) free((MALLOC_P *)cp);
 	    return(0);
@@ -157,7 +175,7 @@ printchdevname_again:
 /*
  * Search for clone parent.
  */
-	if (Lf->is_stream && Clone && (*dev == DevDev)) {
+	if ((nty == N_CHR) && Lf->is_stream && Clone && (*dev == DevDev)) {
 	    for (c = Clone; c; c = c->next) {
 		if (GET_MAJ_DEV(*rdev) == GET_MIN_DEV(c->cd.rdev)) {
 
@@ -174,7 +192,7 @@ printchdevname_again:
 /*
  * Search for pseudo device match on major device only.
  */
-	if (*dev == DevDev) {
+	if ((nty == N_CHR) && *dev == DevDev) {
 	    for (p = Pseudo; p; p = p->next) {
 		if (GET_MAJ_DEV(*rdev) == GET_MAJ_DEV(p->pd.rdev)) {
 
