@@ -34,7 +34,7 @@
 #ifndef lint
 static char copyright[] =
 "@(#) Copyright 1994 Purdue Research Foundation.\nAll rights reserved.\n";
-static char *rcsid = "$Id: main.c,v 1.38 2001/11/01 20:19:44 abe Exp $";
+static char *rcsid = "$Id: main.c,v 1.40 2002/04/23 12:25:56 abe Exp $";
 #endif
 
 
@@ -89,6 +89,16 @@ main(argc, argv)
 	    Pn++;
 	else
 	    Pn = argv[0];
+/*
+ * Make sure stderr, stdout, and stdin are open descriptors.  Open /dev/null
+ * for ones that aren't.  Be terse.
+ */
+	while (((i = open("/dev/null", O_RDWR, 0)) >= 0) && (i < 2))
+	    ;
+	if (i < 0)
+	    Exit(1);
+	if (i > 2)
+	    (void) close(i);
 
 #if	defined(HASSETLOCALE)
 /*
