@@ -32,7 +32,7 @@
 #ifndef lint
 static char copyright[] =
 "@(#) Copyright 1994 Purdue Research Foundation.\nAll rights reserved.\n";
-static char *rcsid = "$Id: print.c,v 1.41 2002/01/07 12:16:35 abe Exp $";
+static char *rcsid = "$Id: print.c,v 1.42 2002/02/26 15:06:48 abe Exp $";
 #endif
 
 
@@ -1867,30 +1867,18 @@ printname(nl)
 		ps++;
 	    goto print_nma;
 	}
-	if ((Lf->ntype == N_CHR) && Lf->dev_def && Lf->rdev_def
-	&&  printchdevname(&Lf->dev, &Lf->rdev, 0))
+	if (((Lf->ntype == N_BLK) || (Lf->ntype == N_CHR))
+	&&  Lf->dev_def && Lf->rdev_def
+	&&  printdevname(&Lf->dev, &Lf->rdev, 0, Lf->ntype))
 	{
 
 	/*
-	 * If this is a character device and it has a name, print it.
+	 * If this is a block or character device and it has a name, print it.
 	 */
 	    ps++;
 	    goto print_nma;
 	}
 
-#if	defined(HASBLKDEV)
-	if (Lf->ntype == N_BLK && Lf->dev_def && Lf->rdev_def
-	&&  printbdevname(&Lf->dev, &Lf->rdev, 0))
-	{
-
-	/*
-	 * If this is a block device and it has a name, print it.
-	 */
-	    ps++;
-	    goto print_nma;
-	}
-#endif	/* defined(HASBLKDEV) */
-
 	if (Lf->is_com) {
 
 	/*
