@@ -32,7 +32,7 @@
 #ifndef lint
 static char copyright[] =
 "@(#) Copyright 1994 Purdue Research Foundation.\nAll rights reserved.\n";
-static char *rcsid = "$Id: proc.c,v 1.32 2002/01/16 15:11:51 abe Exp $";
+static char *rcsid = "$Id: proc.c,v 1.33 2002/04/19 12:00:55 abe Exp $";
 #endif
 
 
@@ -766,9 +766,10 @@ print_fflags(ffg, pof)
 int
 print_proc()
 {
-	char *cp;
-	int lc, st, ty;
+	char buf[128], *cp;
+	int lc, len, st, ty;
 	int rv = 0;
+	unsigned long ul;
 /*
  * If nothing in the process has been selected, skip it.
  */
@@ -910,24 +911,57 @@ print_proc()
 		}
 	    }
 	    if (FieldSel[LSOF_FIX_DEVN].st && Lf->dev_def) {
-		(void) printf("%c0x%lx%c", LSOF_FID_DEVN,
-		    (unsigned long)Lf->dev, Terminator);
+		if (sizeof(unsigned long) > sizeof(dev_t))
+		    ul = (unsigned long)((unsigned int)Lf->dev);
+		else
+		    ul = (unsigned long)Lf->dev;
+		(void) printf("%c0x%lx%c", LSOF_FID_DEVN, ul, Terminator);
 		lc++;
 	    }
 	    if (FieldSel[LSOF_FIX_RDEV].st && Lf->rdev_def) {
-		(void) printf("%c0x%lx%c", LSOF_FID_RDEV,
-		    (unsigned long)Lf->rdev, Terminator);
+		if (sizeof(unsigned long) > sizeof(dev_t))
+		    ul = (unsigned long)((unsigned int)Lf->rdev);
+		else
+		    ul = (unsigned long)Lf->rdev;
+		(void) printf("%c0x%lx%c", LSOF_FID_RDEV, ul, Terminator);
 		lc++;
 	    }
 	    if (FieldSel[LSOF_FIX_SIZE].st && Lf->sz_def) {
 		putchar(LSOF_FID_SIZE);
-		(void) printf(SzOffFmt_d, Lf->sz);
+
+#if	defined(HASPRINTSZ)
+		cp = HASPRINTSZ(Lf);
+#else	/* !defined(HASPRINTSZ) */
+		(void) snpf(buf, sizeof(buf), SzOffFmt_d, Lf->sz);
+		cp = buf;
+#endif	/* defined(HASPRINTSZ) */
+
+		(void) printf("%s", cp);
 		putchar(Terminator);
 		lc++;
 	    }
 	    if (FieldSel[LSOF_FIX_OFFSET].st && Lf->off_def) {
 		putchar(LSOF_FID_OFFSET);
-		(void) printf(SzOffFmt_d, Lf->off);
+
+#if	defined(HASPRINTOFF)
+		cp = HASPRINTOFF(Lf, 0);
+#else	/* !defined(HASPRINTOFF) */
+		(void) snpf(buf, sizeof(buf), SzOffFmt_0t, Lf->off);
+		cp = buf;
+#endif	/* defined(HASPRINTOFF) */
+
+		len = strlen(cp);
+		if (OffDecDig && len > (OffDecDig + 2)) {
+
+#if	defined(HASPRINTOFF)
+		    cp = HASPRINTOFF(Lf, 1);
+#else	/* !defined(HASPRINTOFF) */
+		    (void) snpf(buf, sizeof(buf), SzOffFmt_x, Lf->off);
+		    cp = buf;
+#endif	/* defined(HASPRINTOFF) */
+
+		}
+		(void) printf("%s", cp);
 		putchar(Terminator);
 		lc++;
 	    }
